@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -79,16 +79,6 @@ namespace GAGGUI
 		VALUE_CHANGED,
 	};
 	
-	//! Colors used by GUI element
-	namespace ColorTheme
-	{
-		extern GAGCore::Color frontColor; //!< front elements color
-		extern GAGCore::Color frontFrameColor; //!< front frame elements color
-		extern GAGCore::Color listSelectedElementColor;
-		extern GAGCore::Color backColor; //!< background color
-		extern GAGCore::Color backOverlayColor; //!< overlay background color
-	}
-	
 	class Screen;
 	
 	//! A widget is a GUI block element
