@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 */
 
 #include <GUIBase.h>
+#include <GUIStyle.h>
 #include <assert.h>
 #include <GraphicContext.h>
 #include <cmath>
@@ -30,16 +31,6 @@ using namespace GAGCore;
 
 namespace GAGGUI
 {
-	namespace ColorTheme
-	{
-		// for green theme
-		Color frontColor = Color(255, 255, 255);
-		Color frontFrameColor = Color(0, 200, 100);
-		Color listSelectedElementColor = Color(170, 170, 240);
-		Color backColor = Color(0, 0, 0);
-		Color backOverlayColor = Color(0, 0, 40);
-	}
-	
 	// this function support base unicode (UCS16)
 	void UCS16toUTF8(Uint16 ucs16, char utf8[4])
 	{
@@ -410,13 +401,7 @@ namespace GAGGUI
 		int x, y, w, h;
 		getScreenPos(&x, &y, &w, &h);
 		
-		parent->getSurface()->drawRect(x, y, w, h, ColorTheme::frontFrameColor);
-		
-		unsigned val = getNextHighlightValue();
-		if (val > 0)
-		{
-			parent->getSurface()->drawRect(x+1, y+1, w-2, h-2, ColorTheme::frontColor.applyAlpha(val));
-		}
+		Style::style->drawFrame(parent->getSurface(), x, y, w, h, getNextHighlightValue());
 	}
 	
 	Screen::Screen()
@@ -656,7 +641,7 @@ namespace GAGGUI
 	
 	void Screen::paint(void)
 	{
-		gfx->drawFilledRect(0, 0, getW(), getH(), ColorTheme::backColor);
+		gfx->drawFilledRect(0, 0, getW(), getH(), Style::style->backColor);
 	}
 	
 	int Screen::getW(void)
@@ -723,6 +708,7 @@ namespace GAGGUI
 	
 	void OverlayScreen::paint(void)
 	{
-		gfx->drawFilledRect(0, 0, getW(), getH(), ColorTheme::backOverlayColor);
+		gfx->drawFilledRect(0, 0, getW(), getH(), Style::style->backOverlayColor);
+		Style::style->drawFrame(gfx, 0, 0, getW(), getH(), Color::ALPHA_TRANSPARENT);
 	}
 }
