@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 */
 
 #include <GUIRatio.h>
+#include <GUIStyle.h>
 #include <Toolkit.h>
 #include <GraphicContext.h>
 #include <assert.h>
@@ -160,9 +161,10 @@ namespace GAGGUI
 		HighlightableWidget::paint();
 		
 		if (pressed)
-			parent->getSurface()->drawRect(x+value+1, y+1, size-2, h-2, ColorTheme::frontColor);
+			parent->getSurface()->drawFilledRect(x+value+1, y+1, size-2, h-2, Style::style->highlightColor);
 		else
-			parent->getSurface()->drawRect(x+value+1, y+1, size-2, h-2, ColorTheme::frontFrameColor);
+			parent->getSurface()->drawRect(x+value+1, y+1, size-2, h-2, Style::style->frameColor);
+		//Style::style->drawFrame(parent->getSurface(), x+value+1, y+1, size-2, h-2, Color::ALPHA_TRANSPARENT);
 	
 		// We center the string
 		std::stringstream g;
