@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 */
 
 #include <GUITextArea.h>
+#include <GUIStyle.h>
 #include <Toolkit.h>
 #include <GraphicContext.h>
 #include <StreamBackend.h>
@@ -65,7 +66,7 @@ namespace GAGGUI
 	}
 	
 	TextArea::TextArea(int x, int y, int w, int h, Uint32 hAlign, Uint32 vAlign, const char *font, const std::string &tooltip, const std::string &tooltipFont, bool readOnly, const char *text, const char *spritelocation)
-		: RectangularWidget(tooltip, tooltipFont)
+		: HighlightableWidget(tooltip, tooltipFont)
 	{
 		this->x = x;
 		this->y = y;
@@ -478,10 +479,11 @@ namespace GAGGUI
 		
 		assert(parent);
 		assert(parent->getSurface());
-	
+		
+		HighlightableWidget::paint();
+		
 		areaHeight=(h-8)/charHeight;
 		parent->getSurface()->setClipRect(x, y, w, h);
-		parent->getSurface()->drawRect(x, y, w, h, ColorTheme::frontFrameColor);
 		
 		for (unsigned i=0;(i<areaHeight)&&((signed)i<(signed)(lines.size()-areaPos));i++)
 		{
@@ -512,7 +514,7 @@ namespace GAGGUI
 		{
 			int xPos = x+4+cursorScreenPosY;
 			int yPos = y+4+(charHeight*(cursorPosY-areaPos));
-			parent->getSurface()->drawLine(xPos, yPos, xPos, yPos + charHeight, ColorTheme::frontColor);
+			parent->getSurface()->drawLine(xPos, yPos, xPos, yPos + charHeight, Style::style->textColor);
 		}
 		parent->getSurface()->setClipRect();
 	}
