@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -1328,7 +1328,7 @@ namespace GAGCore
 	
 	void DrawableSurface::drawAlphaMap(const std::valarray<float> &map, int mapW, int mapH, int x, int y, int cellW, int cellH, const Color &color)
 	{
-		assert(mapW * mapH <= map.size());
+		assert(mapW * mapH <= static_cast<int>(map.size()));
 		
 		for (int dy=0; dy < mapH-1; dy++)
 			for (int dx=0; dx < mapW-1; dx++)
@@ -1337,7 +1337,7 @@ namespace GAGCore
 	
 	void DrawableSurface::drawAlphaMap(const std::valarray<unsigned char> &map, int mapW, int mapH, int x, int y, int cellW, int cellH, const Color &color)
 	{
-		assert(mapW * mapH <= map.size());
+		assert(mapW * mapH <= static_cast<int>(map.size()));
 		
 		for (int dy=0; dy < mapH-1; dy++)
 			for (int dx=0; dx < mapW-1; dx++)
@@ -1691,7 +1691,7 @@ namespace GAGCore
 		#ifdef HAVE_OPENGL
 		if (_gc->optionFlags & GraphicContext::USEGPU)
 		{
-			assert(mapW * mapH <= map.size());
+			assert(mapW * mapH <= static_cast<int>(map.size()));
 			
 			float fr = 255.0f*(float)color.r;
 			float fg = 255.0f*(float)color.g;
@@ -1722,7 +1722,7 @@ namespace GAGCore
 		#ifdef HAVE_OPENGL
 		if (_gc->optionFlags & GraphicContext::USEGPU)
 		{
-			assert(mapW * mapH <= map.size());
+			assert(mapW * mapH <= static_cast<int>(map.size()));
 			
 			glState.doBlend(1);
 			glState.doTexture(0);
