@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 #include <Stream.h>
 #include <stdlib.h>
 #include <algorithm>
+#include <climits>
 
 #include "Building.h"
 #include "BuildingType.h"
@@ -428,7 +429,8 @@ void Building::loadCrossRef(GAGCore::InputStream *stream, BuildingsTypes *types,
 			std::ostringstream oss;
 			oss << "unitsInsideSubscribe[" << i << "]";
 			Unit *unit = owner->myUnits[Unit::GIDtoID(stream->readUint16(oss.str().c_str()))];
-		}
+			assert(unit);
+		} 
 		stream->readSint32("subscriptionInsideTimer");
 	}
 
@@ -616,7 +618,7 @@ void Building::launchConstruction(Sint32 unitWorking, Sint32 unitWorkingFuture)
 	}
 }
 
-void Building::cancelConstruction(void)
+void Building::cancelConstruction(Sint32 unitWorking)
 {
 	Sint32 recoverTypeNum=typeNum;
 	BuildingType *recoverType=type;
@@ -687,7 +689,7 @@ void Building::cancelConstruction(void)
 		maxUnitWorking=maxUnitWorkingPreferred;
 	else
 		maxUnitWorking=0;
-	maxUnitWorkingLocal=maxUnitWorking;
+	maxUnitWorkingLocal=unitWorking; //maxUnitWorking;
 	maxUnitInside=type->maxUnitInside;
 	updateCallLists();
 	updateUnitsWorking();
@@ -856,7 +858,10 @@ void Building::updateConstructionState(void)
 	{
 		if (!isHardSpaceForBuildingSite())
 		{
-			cancelConstruction();
+			//this is semi-faulty code and needs to be fixed later
+			//anytime a building is upgraded but unable to do so it reverts to 
+			//one worker working instead of previous value
+			cancelConstruction(1);
 		}
 		else if ((unitsWorking.size()==0) && (unitsInside.size()==0))
 		{
@@ -1212,7 +1217,6 @@ void Building::addForbiddenZoneToUpgradeArea(void)
 			owner->map->addHiddenForbidden(owner->map->normalizeX(newPosX+nx), owner->map->normalizeY(newPosY+ny), owner->teamNumber); 
 		}
 	}
-	owner->map->computeLocalForbidden(0);
 }
 
 
@@ -1224,9 +1228,9 @@ void Building::removeForbiddenZoneFromUpgradeArea(void)
 
 	int targetLevelTypeNum=-1;
 	if (constructionResultState==UPGRADE)
-		targetLevelTypeNum=type->nextLevel;
+		targetLevelTypeNum=type->level;
 	else if (constructionResultState==REPAIR)
-		targetLevelTypeNum=type->prevLevel;
+		targetLevelTypeNum=type->level;
 	else
 		assert(false);
 
@@ -1514,7 +1518,7 @@ void Building::subscribeForFlagingStep()
 				for(int n=0; n<1024; ++n)
 				{
 					Unit* unit=owner->myUnits[n];
-					if(unit==NULL || unit->activity != Unit::ACT_RANDOM)
+					if(unit==NULL || unit->activity != Unit::ACT_RANDOM || unit->medical != Unit::MED_FREE)
 						continue;
 			  	 	if(!canUnitWorkHere(unit))
 			  		  	continue;
@@ -1544,7 +1548,7 @@ void Building::subscribeForFlagingStep()
 				for(int n=0; n<1024; ++n)
 				{
 					Unit* unit=owner->myUnits[n];
-					if(unit==NULL || unit->activity != Unit::ACT_RANDOM)
+					if(unit==NULL || unit->activity != Unit::ACT_RANDOM || unit->medical != Unit::MED_FREE)
 						continue;
 			  	 	if(!canUnitWorkHere(unit))
 			  		  	continue;
@@ -1571,7 +1575,7 @@ void Building::subscribeForFlagingStep()
 				for(int n=0; n<1024; ++n)
 				{
 					Unit* unit=owner->myUnits[n];
-					if(unit==NULL || unit->activity != Unit::ACT_RANDOM)
+					if(unit==NULL || unit->activity != Unit::ACT_RANDOM || unit->medical != Unit::MED_FREE)
 						continue;
 			  	 	if(!canUnitWorkHere(unit))
 			  		  	continue;
@@ -1994,6 +1998,25 @@ void Building::turretStep(void)
 
 }
 
+
+
+void Building::clearingFlagStep()
+{
+	if (unitsWorking.size()<(unsigned)maxUnitWorking)
+		for (int canSwim=0; canSwim<2; canSwim++)
+			if (localRessourcesCleanTime[canSwim]++>125) // Update every 5[s]
+			{
+				if (!owner->map->updateLocalRessources(this, canSwim))
+				{
+					for (std::list<Unit *>::iterator it=unitsWorking.begin(); it!=unitsWorking.end(); ++it)
+						(*it)->standardRandomActivity();
+					unitsWorking.clear();
+				}
+			}
+}
+
+
+
 void Building::kill(void)
 {
 	fprintf(logFile, "kill gid=%d buildingState=%d\n", gid, buildingState);
