@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,10 +32,10 @@
 
 ChooseMapScreen::ChooseMapScreen(const char *directory, const char *extension, bool recurse)
 {
-	ok = new TextButton(440, 360, 180, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "", -1, -1, "menu", Toolkit::getStringTable()->getString("[ok]"), OK, 13);
+	ok = new TextButton(440, 360, 180, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[ok]"), OK, 13);
 	addWidget(ok);
 	
-	cancel = new TextButton(440, 420, 180, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "", -1, -1, "menu", Toolkit::getStringTable()->getString("[Cancel]"), CANCEL, 27);
+	cancel = new TextButton(440, 420, 180, 40, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[Cancel]"), CANCEL, 27);
 	addWidget(cancel);
 	
 	fileList = new Glob2FileList(20, 60, 180, 400, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", directory, extension, recurse);
@@ -52,7 +52,7 @@ ChooseMapScreen::ChooseMapScreen(const char *directory, const char *extension, b
 	else if (strcmp(directory, "games") == 0)
 	{
 		title = new Text(0, 18, ALIGN_FILL, ALIGN_SCREEN_CENTERED, "menu", Toolkit::getStringTable()->getString("[choose game]"));
-		deleteMap = new TextButton(220, 430, 200, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "", -1, -1, "standard", Toolkit::getStringTable()->getString("[Delete game]"), DELETEGAME);
+		deleteMap = new TextButton(220, 430, 200, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", Toolkit::getStringTable()->getString("[Delete game]"), DELETEGAME);
 		addWidget(deleteMap);
 	}
 	else
@@ -71,8 +71,14 @@ ChooseMapScreen::ChooseMapScreen(const char *directory, const char *extension, b
 	mapDate=new Text(440, 60+128+125, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, "standard", "", 180);
 	addWidget(mapDate);
 	
-	globalContainer->settings.tempVarPrestige = 3000;
-	prestigeRatio=new Number(20, 20, 100, 18, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, 18, "menu");
+	globalContainer->settings.tempVarPrestige = 0;
+	useNewPrestige = false;
+	useVarPrestige=new OnOffButton(466, 37, 20, 20, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, useNewPrestige, useNewPrestige);
+	addWidget(useVarPrestige);
+	varPrestigeText=new Text(460, 37, ALIGN_FILL, ALIGN_SCREEN_CENTERED, "standard", "Custom Prestige");
+	addWidget(varPrestigeText);
+	
+	prestigeRatio=new Number(466, 15, 100, 18, ALIGN_SCREEN_CENTERED, ALIGN_SCREEN_CENTERED, 18, "menu");
 	prestigeRatio->add(0);
 	prestigeRatio->add(0);
 	prestigeRatio->add(100);
@@ -144,6 +150,19 @@ void ChooseMapScreen::onAction(Widget *source, Action action, int par1, int par2
 		}
 		delete stream;
 	}
+	else if (action==BUTTON_STATE_CHANGED)
+	{
+		if (useVarPrestige->getState() == false)
+		{
+			prestigeRatio->visible=false;
+			globalContainer->settings.tempVarPrestige = 3000;
+		}
+		else if (useVarPrestige->getState() == true)
+		{
+			prestigeRatio->visible=true;
+			globalContainer->settings.tempVarPrestige=(prestigeRatio->getNth() - 1) * 100;
+		}
+	}
 	else if (action==NUMBER_ELEMENT_SELECTED)
 	{
 		if (prestigeRatio->getNth() == 0)
