@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <Stream.h>
 #include <StreamFilter.h>
 #include <BinaryStream.h>
+#include <GUIStyle.h>
 using namespace GAGCore;
 
 #include "GUIMapPreview.h"
@@ -214,7 +215,7 @@ void MapPreview::paint(void)
 	{
 		/*parent->getSurface()->drawLine(x, y, x+127, y+127, 255, 0, 0);
 		parent->getSurface()->drawLine(x+127, y, x, y+127, 255, 0, 0);*/
-		parent->getSurface()->drawRect(x, y, 128, 128, ColorTheme::frontColor);
+		/*parent->getSurface()->drawRect(x, y, 128, 128, ColorTheme::frontColor);*/
 		Font *standardFont = Toolkit::getFont("standard");
 		assert(standardFont);
 		const char *line0 = Toolkit::getStringTable()->getString("[GUIMapPreview text 0]");
@@ -225,4 +226,5 @@ void MapPreview::paint(void)
 		parent->getSurface()->drawString(x+((128-sw0)>>1), y+64-sh, standardFont, line0);
 		parent->getSurface()->drawString(x+((128-sw1)>>1), y+64, standardFont, line1);
 	}
+	Style::style->drawFrame(parent->getSurface(), x, y, 128, 128, Color::ALPHA_TRANSPARENT);
 }
