@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <functional>
 #include <algorithm>
 #include <sstream>
+#include <cmath>
 
 #include <FileManager.h>
 #include <GraphicContext.h>
@@ -106,8 +107,6 @@ void Game::init(GameGUI *gui)
 
     //If the GameGUI provided is not NULL, meaning that this is a real game not a
 	//map edit, that initialize the preset numbers of units to assign to buildings
-	if(gui)
-		gui->initUnitCount();
 	
 	if (globalContainer->runNoX)
 		minimap=NULL;
@@ -662,7 +661,8 @@ void Game::executeOrder(Order *order, int localPlayer)
 		{
 			if (!isPlayerAlive)
 				break;
-			Uint16 gid=((OrderCancelConstruction *)order)->gid;
+			OrderConstruction *oc = ((OrderConstruction *)order);
+			Uint16 gid=oc->gid;
 			int team=Building::GIDtoTeam(gid);
 			int id=Building::GIDtoID(gid);
 			Team *t=teams[team];
@@ -670,7 +670,7 @@ void Game::executeOrder(Order *order, int localPlayer)
 			if (b)
 			{
 				fprintf(logFile, "ORDER_CANCEL_CONSTRUCTION");
-				b->cancelConstruction();
+				b->cancelConstruction(oc->unitWorking);
 			}
 		}
 		break;
@@ -2153,15 +2153,20 @@ inline void Game::drawMapGroundBuildings(int left, int top, int right, int bot,
 
 inline void Game::drawMapAreas(int left, int top, int right, int bot, int sw, int sh, int viewportX, int viewportY, int localTeam, Uint32 drawOptions)
 {
+	static int areaAnimationTick = 0;
+	const int clearingAreaBaseFrame = 0;
+	const int guardAreaBaseFrame = 8;
+	const int forbiddenAreaBaseFrame = 16;
 	if ((drawOptions & DRAW_AREA) != 0)
+	{
 		for (int y=top; y<bot; y++)
 			for (int x=left; x<right; x++)
 			{
 				if (map.isForbiddenLocal(x+viewportX, y+viewportY))
 				{
-					globalContainer->gfx->drawLine((x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 128, 0, 0);
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 32+(x<<5), 16+(y<<5), 128, 0, 0);
-					globalContainer->gfx->drawLine((x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 128, 0, 0);
+					int randId = (x+viewportX) * 7919 + (y+viewportY) * 17;
+					int frame = ((randId + areaAnimationTick) % 16) / 2;
+					globalContainer->gfx->drawSprite((x<<5), (y<<5), globalContainer->areas, forbiddenAreaBaseFrame + frame);
 					
 					if (!map.isForbiddenLocal(x+viewportX, y+viewportY-1))
 						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 255, 0, 0);
@@ -2175,9 +2180,9 @@ inline void Game::drawMapAreas(int left, int top, int right, int bot, int sw, in
 				}
 				if (map.isGuardAreaLocal(x+viewportX, y+viewportY))
 				{
-					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), (x<<5), 32+(y<<5), 0, 0, 128);
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), (x<<5), 16+(y<<5), 0, 0, 128);
-					globalContainer->gfx->drawLine(32+(x<<5), 16+(y<<5), 16+(x<<5), 32+(y<<5), 0, 0, 128);
+					int randId = (x+viewportX) * 5477 + (y+viewportY) * 13;
+					int frame = (randId + areaAnimationTick) % 8;
+					globalContainer->gfx->drawSprite((x<<5), (y<<5), globalContainer->areas, guardAreaBaseFrame + frame);
 					
 					if (!map.isGuardAreaLocal(x+viewportX, y+viewportY-1))
 						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 0, 0, 255);
@@ -2191,10 +2196,9 @@ inline void Game::drawMapAreas(int left, int top, int right, int bot, int sw, in
 				}
 				if (map.isClearAreaLocal(x+viewportX, y+viewportY))
 				{
-					globalContainer->gfx->drawLine(16+(x<<5), (y<<5), 16+(x<<5), 32+(y<<5), 128, 128, 0);
-//					globalContainer->gfx->drawLine(32+(x<<5), (y<<5), 32+(x<<5), 32+(y<<5), 128, 128, 0);
-					//globalContainer->gfx->drawLine(8+(x<<5), (y<<5), 8+(x<<5), 32+(y<<5), 128, 128, 0);
-					//globalContainer->gfx->drawLine(24+(x<<5), (y<<5), 24+(x<<5), 32+(y<<5), 128, 128, 0);
+					int randId = (x+viewportX) * 7451 + (y+viewportY) * 23;
+					int frame = (randId + areaAnimationTick) % 8;
+					globalContainer->gfx->drawSprite((x<<5), (y<<5), globalContainer->areas, clearingAreaBaseFrame + frame, 200);
 					
 					if (!map.isClearAreaLocal(x+viewportX, y+viewportY-1))
 						globalContainer->gfx->drawHorzLine((x<<5), (y<<5), 32, 255, 255, 0);
@@ -2228,6 +2232,8 @@ inline void Game::drawMapAreas(int left, int top, int right, int bot, int sw, in
 						}
 				}
 			}
+		areaAnimationTick++;
+	}
 }
 
 inline void Game::drawMapAirUnits(int left, int top, int right, int bot, int sw, int sh, int viewportX, int viewportY, int localTeam, Uint32 drawOptions)
@@ -2420,48 +2426,37 @@ inline void Game::drawMapOverlayMaps(int left, int top, int right, int bot, int
 			{
 				int rx=(x+viewportX)%map.getW();
 				int ry=(y+viewportY)%map.getH();
-				if((*overlayMap)[latest->getPos(rx, ry)])
+				if (globalContainer->settings.optionFlags & GlobalContainer::OPTION_LOW_SPEED_GFX)
 				{
-					if (globalContainer->settings.optionFlags & GlobalContainer::OPTION_LOW_SPEED_GFX)
+					if((*overlayMap)[latest->getPos(rx, ry)])
 					{
 						const int value_c=(*overlayMap)[latest->getPos(rx, ry)];
-						const int alpha_c=40+int(float(160)/float(overlayMax) * float(value_c));
+						const int alpha_c=int(float(200)/float(overlayMax) * float(value_c));
 						globalContainer->gfx->drawFilledRect((x<<5), (y<<5), 32, 32, Color(overlayColor.r, overlayColor.g, overlayColor.b, alpha_c));
 					}
-					else
+				}
+				else
+				{
+					for(int px=0; px<4; ++px)
 					{
-						const int value_c=(*overlayMap)[latest->getPos(rx, ry)];
-						const int value_u=(*overlayMap)[latest->getPos(rx, ry-1)];
-						const int value_d=(*overlayMap)[latest->getPos(rx, ry+1)];
-						const int value_l=(*overlayMap)[latest->getPos(rx-1, ry)];
-						const int value_r=(*overlayMap)[latest->getPos(rx+1, ry)];
-						const int alpha_c=int(float(200)/float(overlayMax) * float(value_c));
-						const int alpha_u=int(float(200)/float(overlayMax) * float(value_u));
-						const int alpha_d=int(float(200)/float(overlayMax) * float(value_d));
-						const int alpha_l=int(float(200)/float(overlayMax) * float(value_l));
-						const int alpha_r=int(float(200)/float(overlayMax) * float(value_r));
-//						const float edge_u_alpha=float(alpha_u+alpha_c)/2;
-//						const float edge_l_alpha=float(alpha_l+alpha_c)/2;
-//						const float edge_r_alpha=float(alpha_r+alpha_c)/2;
-//						const float edge_d_alpha=float(alpha_d+alpha_c)/2;
-						const float edge_u_alpha=float(alpha_u);
-						const float edge_l_alpha=float(alpha_l);
-						const float edge_r_alpha=float(alpha_r);
-						const float edge_d_alpha=float(alpha_d);
-						const float vertical_increment=float(edge_u_alpha - edge_d_alpha)/float(32);
-						const float horizontal_increment=float(edge_l_alpha - edge_r_alpha)/float(32);
-						for(int px=0; px<4; ++px)
+						for(int py=0; py<4; ++py)
 						{
-							for(int py=0; py<4; ++py)
-							{
-	
-								const int pby=(4-py)*8;
-								const int pbx=(4-px)*8;
-								const float vertical_g=float(vertical_increment*pby+edge_d_alpha);
-								const float horizontal_g=float(horizontal_increment*pbx+edge_r_alpha);
-								int alpha=int(horizontal_g + vertical_g)/2;
-								globalContainer->gfx->drawFilledRect((x<<5)+px*8, (y<<5)+py*8, 8, 8, Color(overlayColor.r, overlayColor.g, overlayColor.b, alpha));
-							}
+							//fx and fy represent how far along the gradient the values should be
+							float fx = (float(px)/4.0f);
+							float fy = (float(py)/4.0f);
+							//bx and by represent the base position. Since the maximum height
+							//is at the center if the square, pixels before this are interpolated
+							//between the squares that are before this one
+							int b_val=(*overlayMap)[latest->getPos(rx, ry)];
+							int d_val=(*overlayMap)[latest->getPos(rx, map.normalizeY(ry+1))];
+							int r_val=(*overlayMap)[latest->getPos(map.normalizeX(rx+1), ry)];
+							int dr_val=(*overlayMap)[latest->getPos(map.normalizeX(rx+1), map.normalizeY(ry+1))];
+							float n_top = interpolateValues(b_val, r_val, fx);
+							float n_bottom = interpolateValues(d_val, dr_val, fx);
+							float n_vertical = interpolateValues(n_top, n_bottom, fy);
+							const int alpha_c=int(float(200)/float(overlayMax) * float(n_vertical));
+							if(alpha_c>0)
+								globalContainer->gfx->drawFilledRect((x<<5)+px*8, (y<<5)+py*8, 8, 8, Color(overlayColor.r, overlayColor.g, overlayColor.b, alpha_c));
 						}
 					}
 				}
@@ -2470,35 +2465,52 @@ inline void Game::drawMapOverlayMaps(int left, int top, int right, int bot, int
 	}
 }
 
+
+float Game::interpolateValues(float a, float b, float x)
+{
+	float ft = 3.141592653f * x;
+	float f = (1.0f - std::cos(ft)) * 0.5f;
+	return  a*(1.0-f) + b*f;
+}
+	
+
 void Game::drawMap(int sx, int sy, int sw, int sh, int viewportX, int viewportY, int localTeam, Uint32 drawOptions)
 {
 	static int time = 0;
+	static DynamicClouds ds(&globalContainer->settings);
 	int left=(sx>>5);
 	int top=(sy>>5);
 	int right=((sx+sw+31)>>5);
 	int bot=((sy+sh+31)>>5);
+	
 	time++;
-
+	
 	drawMapWater(sw, sh, viewportX, viewportY, time);
 	drawMapTerrain(left, top, right, bot, viewportX, viewportY, localTeam, drawOptions);
 	drawMapRessources(left, top, right, bot, viewportX, viewportY, localTeam, drawOptions);
 	drawMapGroundUnits(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
 	drawMapDebugAreas(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
 	drawMapGroundBuildings(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
-	drawMapAreas(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
 	drawMapAirUnits(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
+	drawMapAreas(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
 	if((drawOptions & DRAW_SCRIPT_AREAS) != 0)
 		drawMapScriptAreas(left, top, right, bot, viewportX, viewportY);
 	drawMapBulletsExplosionsDeathAnimations(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
-	// draw cloud shadow if we are in high quality
+	
+	// compute and draw cloud shadow if we are in high quality
 	if ((globalContainer->settings.optionFlags & GlobalContainer::OPTION_LOW_SPEED_GFX) == 0)
 	{
-		static DynamicClouds ds(&globalContainer->settings);
-		ds.render(globalContainer->gfx, viewportX, viewportY, sw, sh, time);
+		ds.compute(viewportX, viewportY, sw, sh, time);
+		ds.renderShadow(globalContainer->gfx, sw, sh);
 	}
+	
 	drawMapFogOfWar(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
 	drawMapOverlayMaps(left, top, right, bot, sw, sh, viewportX, viewportY, localTeam, drawOptions);
-
+	
+	// draw cloud overlay if we are in high quality
+	if ((globalContainer->settings.optionFlags & GlobalContainer::OPTION_LOW_SPEED_GFX) == 0)
+		ds.renderOverlay(globalContainer->gfx, sw, sh);
+	
 	// we look on the whole map for buildings
 	// TODO : increase speed, do not count on graphic clipping
 	for (std::list<Building *>::iterator virtualIt=teams[localTeam]->virtualBuildings.begin();
