@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -42,9 +42,10 @@
 // Max packet size for reception in game setup
 #define MAX_PACKET_SIZE 4096
 
-#define NET_PROTOCOL_VERSION 22
+#define NET_PROTOCOL_VERSION 23
 // version 21 changed OrderModifyWarFlag to more generic OrderModifyMinLevelToFlag
 // version 22 added ConfigCheckSum to check if all use has the same file config.
+// version 23 updated to allow custom prestige settings
 
 enum OrderTypes
 {
