@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -323,21 +323,23 @@ bool OrderConstruction::setData(const Uint8 *data, int dataLength)
 OrderCancelConstruction::OrderCancelConstruction(const Uint8 *data, int dataLength)
 :Order()
 {
-	assert(dataLength==2);
+	assert(dataLength==6);
 	bool good=setData(data, dataLength);
 	assert(good);
 }
 
-OrderCancelConstruction::OrderCancelConstruction(Uint16 gid)
+OrderCancelConstruction::OrderCancelConstruction(Uint16 gid, Uint32 unitWorking)
 {
 	assert(gid<32768);
 	this->gid=gid;
+	this->unitWorking=unitWorking;
 }
 
 Uint8 *OrderCancelConstruction::getData(void)
 {
 	assert(sizeof(data) == getDataLength());
 	addUint16(data, this->gid, 0);
+	addUint32(data, this->unitWorking, 2);
 	return data;
 }
 
@@ -346,6 +348,7 @@ bool OrderCancelConstruction::setData(const Uint8 *data, int dataLength)
 	if (dataLength!=getDataLength())
 		return false;
 	this->gid=getUint16(data, 0);
+	this->unitWorking=getUint32(data, 2);
 	memcpy(this->data, data, dataLength);
 	return true;
 }
