@@ -1,7 +1,7 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat, Luc-Olivier de Charrière
   and Martin S. Nyffenegger
-  for any question or comment contact us at nct@ysagoon.com, nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net>, <NuageBleu at gmail dot com>
   or barock@ysagoon.com
 
   This program is free software; you can redistribute it and/or modify
