@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,7 +54,8 @@ Settings::Settings()
 	restoreDefaultShortcuts();
 	tempUnit = 1;
 	tempUnitFuture = 1;
-	//whie a little ugly this is to prevent session.cpp from overriding varPrestige once map is chosen
+	//while a little ugly it is necessary to store varPrestige within settings 
+	//to prevent session.cpp from overriding variable once map is chosen
 	tempVarPrestige = 0;
 	for(int n=0; n<IntBuildingType::NB_BUILDING; ++n)
 	{
@@ -99,7 +100,7 @@ Settings::Settings()
 	defaultUnitsAssigned[IntBuildingType::MARKET_BUILDING][0] = 3;
 
 	cloudPatchSize=16;//the bigger the faster the uglier
-	cloudMaxAlpha=130;//the higher the nicer the clouds the harder the units are visible
+	cloudMaxAlpha=120;//the higher the nicer the clouds the harder the units are visible
 	cloudMaxSpeed=3;
 	cloudWindStability=3550;//how much will the wind change
 	cloudStability=1300;//how much will the clouds change shape
