@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */
 
+#include <climits>
 //#include <float.h>
 #include <math.h>
 
@@ -945,7 +946,7 @@ bool Team::prioritize_building(Building* lhs, Building* rhs)
 void Team::add_building_needing_work(Building* b)
 {
 	bool did_find_position=false;
-	for(int i=0; i<buildingsNeedingUnits.size(); ++i)
+	for(unsigned i=0; i<buildingsNeedingUnits.size(); ++i)
 	{
 		if(prioritize_building(b, buildingsNeedingUnits[i]))
 		{
@@ -969,7 +970,7 @@ void Team::remove_building_needing_work(Building* b)
 void Team::updateAllBuildingTasks()
 {
 	std::sort(buildingsNeedingUnits.begin(), buildingsNeedingUnits.end(), Team::prioritize_building);
-	for(int i=0; i<buildingsNeedingUnits.size(); ++i)
+	for(unsigned i=0; i<buildingsNeedingUnits.size(); ++i)
 	{
 		if(buildingsNeedingUnits[i]->type->isVirtual)
 			buildingsNeedingUnits[i]->subscribeForFlagingStep();
@@ -1168,6 +1169,9 @@ void Team::syncStep(void)
 	for (std::list<Building *>::iterator it=turrets.begin(); it!=turrets.end(); ++it)
 		(*it)->turretStep();
 
+	for (std::list<Building *>::iterator it=clearingFlags.begin(); it!=clearingFlags.end(); ++it)
+		(*it)->clearingFlagStep();
+
 	bool isDying= (playersMask==0)
 		|| (!isEnoughFoodInSwarm && nbUsefullUnitsAlone==0 && (nbUsefullUnits==0 || (canFeedUnit.size()==0 && canHealUnit.size()==0)));
 	if (isAlive && isDying)
