@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -121,7 +121,7 @@ void TeamStat::setMapSize(int w, int h)
 
 
 
-int TeamStat::increasePoint(std::vector<int>& numberMap, int& max, int x, int y, Map* map)
+void TeamStat::increasePoint(std::vector<int>& numberMap, int& max, int x, int y, Map* map)
 {
 	//Update the map
 	for(int n=0; n<8; ++n)
@@ -152,7 +152,7 @@ int TeamStat::increasePoint(std::vector<int>& numberMap, int& max, int x, int y,
 
 
 
-int TeamStat::spreadPoint(std::vector<int>& numberMap, int& max, int x, int y, Map* map, int value, int distance)
+void TeamStat::spreadPoint(std::vector<int>& numberMap, int& max, int x, int y, Map* map, int value, int distance)
 {
 	for (int px=x-distance; px<(x+distance); px++)
 	{
