@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2001-2004 Stephane Magnenat & Luc-Olivier de Charrière
-  for any question or comment contact us at nct@ysagoon.com or nuage@ysagoon.com
+  for any question or comment contact us at <stephane at magnenat dot net> or <NuageBleu at gmail dot com>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 #include "LogFileManager.h"
 #include <Stream.h>
 #include <set>
+#include <climits>
 
 Unit::Unit(GAGCore::InputStream *stream, Team *owner, Sint32 versionMinor)
 {
@@ -2330,16 +2331,11 @@ Uint16 Unit::GIDfrom(Sint32 id, Sint32 team)
 //! Return the real armor, taking into account the reduction due to fruits
 int Unit::getRealArmor(bool isMagic) const
 {
-	if (isMagic == false)
-	{
-		int armorReductionPerHappyness = race->getUnitType(typeNum, level[ARMOR])->armorReductionPerHappyness;
-		return performance[ARMOR] - fruitCount * armorReductionPerHappyness;
-	}
-	else if(isMagic == true) //magic bypasses armor yet fruit penalties still apply
-	{
-		int armorReductionPerHappyness = race->getUnitType(typeNum, level[ARMOR])->armorReductionPerHappyness;
+	int armorReductionPerHappyness = race->getUnitType(typeNum, level[ARMOR])->armorReductionPerHappyness;
+	if (isMagic) //magic bypasses armor yet fruit penalties still apply
 		return 0 - fruitCount * armorReductionPerHappyness;
-	}
+	else
+		return performance[ARMOR] - fruitCount * armorReductionPerHappyness;
 }
 
 //! Return the real attack strengh, taking into account the experience level
@@ -2591,5 +2587,3 @@ Uint32 Unit::checkSum(std::vector<Uint32> *checkSumsVector)
 	
 	return cs;
 }
-
-
